@@ -444,7 +444,7 @@ module Debian
 	@selection,@ok,@status = @info['Status'].split
       end
       if @description = @info['Description']
-	@description.gsub!(/\n.*/,"")
+	@description = @description.sub(/\n.*/m,"")
       end
       @filename = nil
       @artab = nil
